from distutils.core import setup

setup(
	name = 'lmadd',
	version = '1.1.0',
	py_modules = ['lmadd'],
	author = 'lumin',
	author_email = 'lumin.vis@gmail.com',
	description = 'A Sum-up, Menus Function',
	)
